<?php
// Include libraries
require_once("Thumbnail.class.php");

class Tester
{
    function Tester()
	{
		
    }
    
    /**
        @desc Permorm general check [server, files, etc.]
        @return array
    */
    function performGeneralCheck()
    {
    	$generalCheckResults = array(); 
    	$criticalError = false;
    	
    	$generalCheckResults[] = array(
    		'errorType' => 'info',
    		'message' => 'PHP '.phpversion().' is installed.'
    	);
    	
    	if ( version_compare(phpversion(), '4.4', '<') ) {
        	$generalCheckResults[] = array(
        		'errorType' => 'fatal',
        		'message' => 'PHP version is lower than needed.'
        	);
        	$criticalError = true;
        }
        
        // Mod Security
		if (function_exists('apache_get_modules')) {
			// we have an apache2
			$apache_modules = apache_get_modules();
			if (in_array("mod_security", $apache_modules)) {
				// modsecurity is installed
				$generalCheckResults[] = array(
	        		'errorType' => 'fatal',
	        		'message' => 'Mod_security is installed.'
	        	);
	        	$criticalError = true;	
			}
		}    
        
        // GD
        if(function_exists('gd_info')) {
            $generalCheckResults[] = array(
        		'errorType' => 'info',
        		'message' => 'GD library is installed.'
        	);
			if(function_exists('imagecreatefromjpeg')) {
                $im = imagecreatefromjpeg('testImage.jpg');
                if(!$im) {                	
                	$generalCheckResults[] = array(
		        		'errorType' => 'fatal',
		        		'message' => 'GD error. Test image creation failed.'
		        	);	
		        	$criticalError = true;
                } else {
                	$generalCheckResults[] = array(
		        		'errorType' => 'info',
		        		'message' => 'GD - image creation test is ok.'
		        	);
		        	
		        	$image = new Thumbnail('testImage.jpg');
                    if( $image->error ) {
                    	$generalCheckResults[] = array(
			        		'errorType' => 'fatal',
			        		'message' => $image->errmsg
			        	);
			        	$criticalError = true;
                    }
                    $image->destruct();
                }
			} else {
				$generalCheckResults[] = array(
	        		'errorType' => 'fatal',
	        		'message' => 'GD error - imagecreatefromjpeg does not exist.'
	        	);
	        	$criticalError = true;
			}
        } else {
        	$generalCheckResults[] = array(
        		'errorType' => 'warning',
        		'message' => 'GD library is not installed on the server.'
        	);
        }

        // Safe mode
        if(ini_get('safe_mode')) {
            $generalCheckResults[] = array(
        		'errorType' => 'fatal',
        		'message' => 'Safe mode is ON.'
        	);
        	$criticalError = true;
        }
        
        // Check if we can create categories folders
    	if(mkdir('testGalleryCategory', 0755)) {    		
    		$generalCheckResults[] = array(
        		'errorType' => 'info',
        		'message' => 'Test category was successfully created.'
        	);
    		// Remove
    		if(is_dir('testGalleryCategory') && !rmdir('testGalleryCategory')) {
	    		$generalCheckResults[] = array(
	        		'errorType' => 'fatal',
	        		'message' => 'Can not remove test category folder. Permission denied.'
	        	);
	        	$criticalError = true;
			} else {
				$generalCheckResults[] = array(
	        		'errorType' => 'info',
	        		'message' => 'Test category was successfully removed.'
	        	);
			}
    	} else {
    		$generalCheckResults[] = array(
        		'errorType' => 'fatal',
        		'message' => 'Can not create test category folder. Permission denied.'
        	);
        	$criticalError = true;
    	}
    	// realpath
    	$rp = realpath(dirname(__FILE__));
    	if(!$rp || strlen($rp) == 0 || empty($rp)) {
    		$generalCheckResults[] = array(
        		'errorType' => 'fatal',
        		'message' => 'PHP realpath function is not enabled or doesn\'t work properly.'
        	);
        	$criticalError = true;
    	}
	        	
        return array("criticalError" => $criticalError, "results" => $generalCheckResults); 
    }
    
    /**
        @desc Delete provided directory
        @return array
    */
    function deleteDirectory($dirname, $only_empty=false) {
       if (!is_dir($dirname))
           return false;
       $dscan = array(realpath($dirname));
       $darr = array();
       while (!empty($dscan)) {
           $dcur = array_pop($dscan);
           $darr[] = $dcur;
           if ($d=opendir($dcur)) {
               while ($f=readdir($d)) {
                   if ($f=='.' || $f=='..')
                       continue;
                   $f=$dcur.'/'.$f;
                   if (is_dir($f))
                       $dscan[] = $f;
                   else
                      unlink($f);
               }
               closedir($d);
           }
       }
       $i_until = ($only_empty)? 1 : 0;
       for ($i=count($darr)-1; $i>=$i_until; $i--) {
           rmdir($darr[$i]);
       }
       return (($only_empty)? (count(scandir)<=2) : (!is_dir($dirname)));
    }

    function cleanUpDirectory( $targetDir ) {
        if(is_dir($targetDir)) {
            if ($handle = opendir($targetDir)) {
                while (false !== ($file = readdir($handle))) {
                    if ($file != "." && $file != ".." && is_file($targetDir.'/'.$file)) {
                        @unlink($targetDir.'/'.$file);
                    }
                }
                closedir($handle);
            }
        }
    }
}

?>