<?php
// Include libraries
require_once("config.php");
require_once("Thumbnail.class.php");
require_once("XPath.class.php");


class Gallery
{
    /**
    * @var array $xmlOptions
    */
    var $xmlOptions;
    /**
    * @var XPath $xPath
    */
    var $xPath;

    function Gallery()
	{
        $this->xmlOptions = array(
            XML_OPTION_CASE_FOLDING => FALSE,
            XML_OPTION_SKIP_WHITE => TRUE
        );
		
        if(is_file(GALLERY_ROOT.GALLERY_XML_FILENAME)) {
        	$this->xPath =& new XPath(GALLERY_ROOT.GALLERY_XML_FILENAME, $this->xmlOptions);
        }
    }
    
    /**
        @desc Check if user is authorized
        @return array
    */
    function checkAuth()
    {
    	// Check file
    	$fp = @fopen( GALLERY_ROOT.'admin/userdata.php', 'r' );
    	if( $fp ) {
	    	$line = rtrim( fgets($fp,1000) );
	    	fclose( $fp );
	        $arr = explode( ",", $line );
	        if($arr[0] && strlen($arr[0]) > 0 && $arr[1] && strlen($arr[1]) == 32) {
	        	session_start();
	    		$username = $_SESSION['username'];
				$password = $_SESSION['password'];
				return array("login" => $this->login($username, $password, true), "userdataValid" => true);	
	        } else {
	        	return array("login" => false, "userdataValid" => false);
	        }     
    	} else {
    		return array("login" => false, "userdataValid" => false);
    	}
    }
    
    /**
        @desc Try to login
        @return boolean
    */
    function login($username, $password, $check = false)
    {
    	if( isset($username) && isset($password) ) {
    		$fp = fopen( GALLERY_ROOT.'admin/userdata.php', 'r' );
	    	$line = rtrim( fgets($fp,1000) );
	    	fclose( $fp );
	        $arr = explode( ",", $line );
	       	if(!$check) $password = md5( $password );  
	        if($arr[0] == $username && $arr[1] == $password) {
	        	$_SESSION['username'] = $username;
	        	$_SESSION['password'] = $password;
	        	return true;
	        } else {
	        	return false;
	        }
	        return true;
    	} else {
    		return false;
    	}
	}
    
    /**
        @desc Permorm general check [server, files, etc.]
        @return array
    */
    function performGeneralCheck()
    {
    	$generalCheckResults = array(); 
    	$criticalError = false;
    	// GD check
        if(!function_exists('gd_info')) {
        	$generalCheckResults[] = array(
        		'errorType' => 'warning',
        		'message' => 'GD library is not installed on the server.'
        	);
        }
        if( is_writable(GALLERY_ROOT.'admin/userdata.php') ) {
        	$generalCheckResults[] = array(
        		'errorType' => 'warning',
        		'message' => 'File that holds gallery auth data is still writable.'
        	);
        }
        // Safe mode
        if(ini_get('safe_mode')) {
            $generalCheckResults[] = array(
        		'errorType' => 'fatal',
        		'message' => 'Safe mode is ON.'
        	);
        	$criticalError = true;
        }
        // Check
        if(!is_dir(GALLERY_ROOT.'admin/uploads')) {
        	$generalCheckResults[] = array(
        		'errorType' => 'info',
        		'message' => 'Default uploads folders doesn\'t exist. Trying to create it.'
        	);
        	// Try to create needed categories
			if(!mkdir(GALLERY_ROOT.'admin/uploads', 0755)) {
            	$generalCheckResults[] = array(
	        		'errorType' => 'warning',
	        		'message' => 'Couldn\'t create default uploads folder.'
	        	);
			} else {
				$generalCheckResults[] = array(
	        		'errorType' => 'info',
	        		'message' => 'Default uploads folder created.'
	        	);
	        	// Try to create big and small categories
	        	if(!mkdir(GALLERY_ROOT.'admin/uploads'.'/big', 0755)) {
	        		$generalCheckResults[] = array(
		        		'errorType' => 'warning',
		        		'message' => 'Couldn\'t create folder "big" inside the folder - admin/uploads.'
		        	);
				}
                if(!mkdir(GALLERY_ROOT.'admin/uploads'.'/small', 0755)) {
					$generalCheckResults[] = array(
		        		'errorType' => 'warning',
		        		'message' => 'Couldn\'t create folder "small" inside the folder - admin/uploads.'
		        	);
				}
			}
        } else {
        	// Check for "big" and "small" folders
			if(is_dir(GALLERY_ROOT.'admin/uploads/big')) {
				// chmod(GALLERY_ROOT.'admin/uploads/big', 0755);
			} else {
				if(!mkdir(GALLERY_ROOT.'admin/uploads/big', 0755)) {
	        		$generalCheckResults[] = array(
		        		'errorType' => 'warning',
		        		'message' => 'Couldn\'t create folder "big" inside the folder - admin/uploads.'
		        	);
		        	$criticalError = true;
				}
			}
			if(is_dir(GALLERY_ROOT.'admin/uploads/small')) {
				// chmod(GALLERY_ROOT.'admin/uploads/small', 0755);
			} else {
				if(!mkdir(GALLERY_ROOT.'admin/uploads/small', 0755)) {
	        		$generalCheckResults[] = array(
		        		'errorType' => 'warning',
		        		'message' => 'Couldn\'t create folder "small" inside the folder - admin/uploads.'
		        	);
		        	$criticalError = true;
				}
			}
        }
        // Check if we can create categories folders
        if(!@mkdir(GALLERY_ROOT.'testCategory', 0755)) {
    		$generalCheckResults[] = array(
        		'errorType' => 'fatal',
        		'message' => 'Couldn\'t create test category folder. Please check folder permissions where your categories are located.'
        	);
        	$criticalError = true;
		} else {
			if(!rmdir(GALLERY_ROOT.'testCategory')) {
				$generalCheckResults[] = array(
	        		'errorType' => 'fatal',
	        		'message' => 'Couldn\'t delete test category folder. Please check folder permissions where your categories are located.'
	        	);
			}
		}
        // Get dirs list
        $dirs = array();
        $dirsLower = array();
        if ($handle = opendir(GALLERY_ROOT)) {
		    while (false !== ($file = readdir($handle))) {
		        if ($file != "." && $file != "..") {
		        	if(is_dir(GALLERY_ROOT.$file)) {
		        		$dirs[] = $file;
		        		$dirsLower[] = strtolower($file);
		        	}
		        }
		    }
		    closedir($handle);
		}
		// Check for data file existence
		if(!$this->xPath) {
			$generalCheckResults[] = array(
        		'errorType' => 'fatal',
        		'message' => 'The xml data file is missing. Please check for tfile_gallery.xml in your server root folder.'
        	);
        	$criticalError = true;
		} else {
			// Check data file 
			if(!is_writable(GALLERY_ROOT.GALLERY_XML_FILENAME)) {
				$generalCheckResults[] = array(
	        		'errorType' => 'fatal',
	        		'message' => 'The xml data file is not writable. Please change file permissions to fix this problem.'
	        	);
			}
			
			$section = $this->xPath->nodeName("//section[@name='".SECTION_DATA."']");
	        if($section) {
	            // Get categories
	            $imagesCategories = $this->xPath->evaluate("//section[@name='".SECTION_DATA."']/category");
	            // Check categories
	            for ($i=0; $i < count($imagesCategories); $i++) {
	                $gallery_images[$i]['id'] = $i;
	                $gallery_images[$i]['category_name'] = $this->xPath->getAttributes($imagesCategories[$i], 'name');
	                $gallery_images[$i]['folderID'] = $this->xPath->getAttributes($imagesCategories[$i], 'folderID');
	                $key = array_search(strtolower($gallery_images[$i]['folderID']), $dirsLower);
	                // Check for folder existence
	                if(in_array(strtolower($gallery_images[$i]['folderID']), $dirsLower)) {
	                	/*
	                	if(!@chmod(GALLERY_ROOT.$gallery_images[$i]['category_name'], 0755)) {
	                		$generalCheckResults[] = array(
				        		'errorType' => 'warning',
				        		'message' => 'Couldn\'t set permissions on the category folder - '.$gallery_images[$i]['category_name'].'.'
				        	);
	    				} else {
	    				*/
	    					// Check for "big" and "small" folders
	    					if(is_dir(GALLERY_ROOT.$gallery_images[$i]['folderID'].'/big')) {
	    						// @chmod(GALLERY_ROOT.$gallery_images[$i]['category_name'].'/big', 0755);
	    					} else {
	    						if(!mkdir(GALLERY_ROOT.$gallery_images[$i]['folderID'].'/big', 0755)) {
					        		$generalCheckResults[] = array(
						        		'errorType' => 'fatal',
						        		'message' => 'Couldn\'t create folder "big" inside the category folder - '.$gallery_images[$i]['folderID'].'.'
						        	);
						        	$criticalError = true;
								}
	    					}
	    					if(is_dir(GALLERY_ROOT.$gallery_images[$i]['folderID'].'/small')) {
	    						// @chmod(GALLERY_ROOT.$gallery_images[$i]['category_name'].'/small', 0755);
	    					} else {
	    						if(!mkdir(GALLERY_ROOT.$gallery_images[$i]['folderID'].'/small', 0755)) {
					        		$generalCheckResults[] = array(
						        		'errorType' => 'fatal',
						        		'message' => 'Couldn\'t create folder "small" inside the category folder - '.$gallery_images[$i]['folderID'].'.'
						        	);
						        	$criticalError = true;
								}
	    					}
	    				// }
	    				// Case
	    				if($gallery_images[$i]['folderID'] != $dirs[$key]) {
	    					// Try to rename
	    					$generalCheckResults[] = array(
				        		'errorType' => 'info',
				        		'message' => 'Directory name has different letter case. Trying to rename - '.$gallery_images[$i]['folderID'].'.'
				        	);
				        	if(!@rename(GALLERY_ROOT.$dirs[$key], GALLERY_ROOT.$gallery_images[$i]['folderID'])) {
	    						$generalCheckResults[] = array(
					        		'errorType' => 'fatal',
					        		'message' => 'Couldn\'t rename category folder - '.$gallery_images[$i]['folderID'].'.'
					        	);
					        	$criticalError = true;
	    					}
	    				}
	                } else {
	                	$generalCheckResults[] = array(
			        		'errorType' => 'warning',
			        		'message' => 'Category folder was not found on the server - '.$gallery_images[$i]['folderID'].'.'
			        	);
			        	// Try to create needed categories
    					if(!mkdir(GALLERY_ROOT.$gallery_images[$i]['folderID'], 0755)) {
                        	$generalCheckResults[] = array(
				        		'errorType' => 'fatal',
				        		'message' => 'Couldn\'t create new category folder - '.$gallery_images[$i]['folderID'].'.'
				        	);
				        	$criticalError = true;
    					} else {
    						$generalCheckResults[] = array(
				        		'errorType' => 'info',
				        		'message' => 'New category folder created - '.$gallery_images[$i]['folderID'].'.'
				        	);
				        	// Try to create big and small categories
				        	if(!mkdir(GALLERY_ROOT.$gallery_images[$i]['folderID'].'/big', 0755)) {
				        		$generalCheckResults[] = array(
					        		'errorType' => 'fatal',
					        		'message' => 'Couldn\'t create folder "big" inside the category folder - '.$gallery_images[$i]['folderID'].'.'
					        	);
					        	$criticalError = true;
							}
	                        if(!mkdir(GALLERY_ROOT.$gallery_images[$i]['folderID'].'/small', 0755)) {
								$generalCheckResults[] = array(
					        		'errorType' => 'fatal',
					        		'message' => 'Couldn\'t create folder "small" inside the category folder - '.$gallery_images[$i]['folderID'].'.'
					        	);
					        	$criticalError = true;
							}
    					}	
                    }
	            }
	        } else {
	            $generalCheckResults[] = array(
	        		'errorType' => 'fatal',
	        		'message' => 'The xml data file is corrupted.'
	        	);
	        	$criticalError = true;
	        }
		}
        return array("criticalError" => $criticalError, "results" => $generalCheckResults); 
    }

    /**
        @desc Return section options by section name
        @return array
    */
    function getSectionOptions($sectionName)
    {
        $sectionOptions = array();
        $section = $this->xPath->nodeName("//section[@name='".$sectionName."']");
        if($section) {
            $options = $this->xPath->evaluate("//section[@name='".$sectionName."']/option");
            for ($i=0; $i < count($options); $i++) {
                $sectionOptions[$this->xPath->getAttributes($options[$i], 'name')] = $this->xPath->getData($options[$i]);
            }
        	return $sectionOptions;
        } else {
            return FALSE;
        }
    }

    /**
        @desc Return gallery options
        @access remote
        @return array
    */
    function getGalleryOptions()
    {
        $galleryDefaults = $this->getSectionOptions(SECTION_DEFAULTS);
        if($galleryDefaults && is_array($galleryDefaults)) {
            // GD
            if(function_exists("gd_info")) {
        		$galleryDefaults['gd'] = 'true';
        	} else {
                $galleryDefaults['gd'] = 'false';
        	}
        	return $galleryDefaults;
        } else {
            return FALSE;
        }
    }

    /**
        @desc Return gallery preferences
        @access remote
        @return array
    */
    function getPreferences()
    {
        return $this->getSectionOptions(SECTION_SETTINGS);
    }

    /**
        @desc Return all the images from the gallery
        @access remote
        @return array
    */
    function getData()
    {
        $gallery_images = array();
        $section = $this->xPath->nodeName("//section[@name='".SECTION_DATA."']");
        if($section) {
            // Get categories
            $imagesCategories = $this->xPath->evaluate("//section[@name='".SECTION_DATA."']/category");
            for ($i=0; $i < count($imagesCategories); $i++) {
                $gallery_images[$i]['id'] = $i;
                $gallery_images[$i]['category_name'] = $this->xPath->getAttributes($imagesCategories[$i], 'name');
                $gallery_images[$i]['folderID'] = $this->xPath->getAttributes($imagesCategories[$i], 'folderID');
                // Category images
                $images = $this->xPath->evaluate($imagesCategories[$i]."/image");
                for ($j=0; $j < count($images); $j++) {
                    $items = $this->xPath->evaluate($images[$j]."/item");
                    for ($k=0; $k < count($items); $k++) {
                        $gallery_images[$i]['images'][$j][$this->xPath->getAttributes($items[$k], 'name')] = $this->clearCDATA( $this->xPath->getData($items[$k]) );
                    }
                    $gallery_images[$i]['images'][$j]['id'] = $j;
                    // Get image info (filename, filesize, image width, image height)
                    $imagePath = GALLERY_ROOT.$gallery_images[$i]['folderID'].'/big/'.$gallery_images[$i]['images'][$j]['imageUrl'];
                    if (file_exists($imagePath)) {
                        if(function_exists("gd_info")) {
                            $image = new Thumbnail($imagePath);
                            if( $image->error ) return array('error' => true, 'message' => $image->errmsg);
                            $gallery_images[$i]['images'][$j]['filesize'] = filesize($imagePath)/1024;
                            $gallery_images[$i]['images'][$j]['width'] = $image->getCurrentWidth();
                            $gallery_images[$i]['images'][$j]['height'] = $image->getCurrentHeight();
                            $image->destruct();
                        } else {
                            $gallery_images[$i]['images'][$j]['filesize'] = filesize($imagePath)/1024;
                            $isize = getimagesize($imagePath);
                            $gallery_images[$i]['images'][$j]['width'] = ($isize[0]) ? $isize[0] : '';
                            $gallery_images[$i]['images'][$j]['height'] = ($isize[1]) ? $isize[1] : '';
                        }
                    } else {
                    	$gallery_images[$i]['images'][$j]['filesize'] = ' ';
                        $gallery_images[$i]['images'][$j]['width'] = '';
                        $gallery_images[$i]['images'][$j]['height'] = '';
                    }
                }
            }
            return $gallery_images;
        } else {
            return array('error' => true, 'message' => 'XML data error. Check tfile_gallery.xml file contents.');
        }
    }

    /**
        @desc Put categories and images to the gallery file
        @access remote
        @return boolean
    */
    function putData($dataObject, $preferences, $options, $imagesToRemove = null, $moveTo = false, $deletedCategories = null)
    {
        $tempXPath =& new XPath('', $this->xmlOptions);
        $tempXPath->importFromString('<section name="'.SECTION_DATA.'"/>');

        // Sort by id
        $sortedDataObject = array();
        for($i = 0; $i < count($dataObject); $i++) {
            $sortedDataObject[$dataObject[$i]['id']] = $dataObject[$i];
        }

        // Delete categories if such exist
        for($i = 0; $i < count($deletedCategories); $i++) {
            if(strlen($deletedCategories[$i]['folderID']) > 0 && file_exists(GALLERY_ROOT.$deletedCategories[$i]['folderID'])) {
                // @chmod(GALLERY_ROOT.$deletedCategories[$i]['name'], 0755);
                if(!$this->deleteDirectory(GALLERY_ROOT.$deletedCategories[$i]['folderID'])) {
                	return array('error' => true, 'message' => 'Couldn\'t delete category folder.');
                }
            }
        }

        for($i = 0; $i < count($sortedDataObject); $i++) {
            // Check if category was deleted
            if(isset($sortedDataObject[$i]['deleteCategory']) && $sortedDataObject[$i]['deleteCategory'] == 'delete') {
                if(file_exists(GALLERY_ROOT.$sortedDataObject[$i]['folderID'])) {
                    // @chmod(GALLERY_ROOT.$sortedDataObject[$i]['name'], 0755);
                    if($this->deleteDirectory(GALLERY_ROOT.$sortedDataObject[$i]['folderID'])) {
                        $this->xPath->removeChild("//section[@name='".SECTION_DATA."']/category[@folderID='".$sortedDataObject[$i]['folderID']."']");
                    } else {
                    	return array('error' => true, 'message' => 'Couldn\'t delete category folder.');
                    }
                }
            } else {
                // Create new gallery folder
                if(isset($sortedDataObject[$i]['newCategory']) && $sortedDataObject[$i]['newCategory'] == 'create') {
                    if(!mkdir(GALLERY_ROOT.$sortedDataObject[$i]['folderID'])) {
                        return array('error' => true, 'message' => 'Couldn\'t create new category folder.');
                    } else {
                        // @chmod(GALLERY_ROOT.$sortedDataObject[$i]['name'], 0755);
                        if(!mkdir(GALLERY_ROOT.$sortedDataObject[$i]['folderID'].'/big')) return array('error' => true, 'message' => 'Couldn\'t create folder inside category folder.');
                        if(!mkdir(GALLERY_ROOT.$sortedDataObject[$i]['folderID'].'/small')) return array('error' => true, 'message' => 'Couldn\'t create folder inside category folder.');
                    }
                }
                // Add new category to XML
                $categoryPath = $tempXPath->appendChild("//section[@name='".SECTION_DATA."']", '<category name="'.$sortedDataObject[$i]['name'].'" folderID="'.$sortedDataObject[$i]['folderID'].'"/>');
                // Images
                for($j = 0; $j < count($sortedDataObject[$i]['images']); $j++) {
                	// Paths
                    $bigImagePath = GALLERY_ROOT.$sortedDataObject[$i]['folderID']."/big/".$sortedDataObject[$i]['images'][$j]['imageUrl'];
                    $smallImagePath = GALLERY_ROOT.$sortedDataObject[$i]['folderID']."/small/".$sortedDataObject[$i]['images'][$j]['imageUrl'];
                    
                    if(isset($sortedDataObject[$i]['images'][$j]['renamePic'])) {
                        // Move files from default uploads folder
                        $imageToRemove = GALLERY_DEFAULT_UPLOADS_PATH."/big/".$sortedDataObject[$i]['images'][$j]['imageUrl'];
                        if(file_exists($imageToRemove) && is_dir(GALLERY_ROOT.$sortedDataObject[$i]['folderID'])) {
                        	copy($imageToRemove, $bigImagePath);
                            @unlink($imageToRemove);
                        }
                        $imageToRemove = GALLERY_DEFAULT_UPLOADS_PATH."/small/".$sortedDataObject[$i]['images'][$j]['imageUrl'];
                        if(file_exists($imageToRemove) && is_dir(GALLERY_ROOT.$sortedDataObject[$i]['folderID'])) {
                            copy($imageToRemove, $smallImagePath);
                            @unlink($imageToRemove);
                        }
                        // Thumbnail
                        if($sortedDataObject[$i]['images'][$j]['renamePic'] == 'createThumbnail') {
                        	if (file_exists($bigImagePath) && function_exists("gd_info")) {
	                            $thumb = new Thumbnail($bigImagePath);
	                            if( $thumb->error ) return array('error' => true, 'message' => $thumb->errmsg);
	                            $thumb->resize($preferences['imageWidth'], $preferences['imageHeight']);
	                            $thumb->save($smallImagePath);
	                            $thumb->destruct();
                        	}
                        } else {
                            // CHeck thumbnail size - resample
                            if (file_exists($smallImagePath) && function_exists("gd_info")) {
	                            $thumb = new Thumbnail($smallImagePath);
	                            if( $thumb->error ) return array('error' => true, 'message' => $thumb->errmsg);
	                            if($thumb->getCurrentWidth() > $preferences['imageWidth'] || $thumb->getCurrentHeight() > $preferences['imageHeight']) {
	                                $thumb->resize($preferences['imageWidth'], $preferences['imageHeight']);
	                                $thumb->save($smallImagePath);
	                            }
	                            $thumb->destruct();
                            }
                        }
                        // Check size of the new uploaded full image
                        if (file_exists($bigImagePath) && function_exists("gd_info")) {
	                        $thumb = new Thumbnail($bigImagePath);
	                        if( $thumb->error ) return array('error' => true, 'message' => $thumb->errmsg);
	                        if($thumb->getCurrentWidth() > $options['maxPreviewWidth'] || $thumb->getCurrentHeight() > $options['maxPreviewHeight']) {
	                            $thumb->resize($options['maxPreviewWidth'], $options['maxPreviewHeight']);
	                            $thumb->save($bigImagePath);
	                        }
	                        $thumb->destruct();
                        }
                    }
                    // ByteArray checking
                	$ba = $sortedDataObject[$i]['images'][$j]['byteArray'];
                	if($ba && $ba->data) {
                		if ($handle = fopen($bigImagePath, 'w')) {
				        	fwrite($handle, $ba->data);
				        	fclose($handle);
				        	// Create thumbnail
				        	if (file_exists($bigImagePath) && function_exists("gd_info")) {
	                            $thumb = new Thumbnail($bigImagePath);
	                            if( $thumb->error ) return array('error' => true, 'message' => $thumb->errmsg);
	                            $thumb->resize($preferences['imageWidth'], $preferences['imageHeight']);
	                            $thumb->save($smallImagePath);
	                            $thumb->destruct();
                        	}
                		}
                	}
                    // Append new node
                    $imageNodeString = '<image><item name="imageUrl">'.$sortedDataObject[$i]['images'][$j]['imageUrl'].'</item><item name="imageComment">'.htmlspecialchars($sortedDataObject[$i]['images'][$j]['imageComment']).'</item></image>';
                    $tempXPath->appendChild($categoryPath, $imageNodeString, FALSE, FALSE);
                }

            }
        }
        $this->xPath->replaceChild("//section[@name='".SECTION_DATA."']", $tempXPath->exportAsXml('',''));

        // Preferences
        foreach ($preferences as $key => $value) {
            if($key == 'length') continue;
            $this->xPath->replaceData("//section[@name='".SECTION_SETTINGS."']/option[@name='".$key."']", $value);
        }

        // Remove images
        if($imagesToRemove && count($imagesToRemove) > 0) {
            // Check 'target' property
            for($i = 0; $i < count($imagesToRemove); $i++) {
                if($imagesToRemove[$i]['target'] && strlen($imagesToRemove[$i]['target']) > 0 && is_dir(GALLERY_ROOT.$imagesToRemove[$i]['target'])) {
                    copy(GALLERY_ROOT.$imagesToRemove[$i]['category']."/big/".$imagesToRemove[$i]['imageUrl'], GALLERY_ROOT.$imagesToRemove[$i]['target']."/big/".$imagesToRemove[$i]['imageUrl']);
                    copy(GALLERY_ROOT.$imagesToRemove[$i]['category']."/small/".$imagesToRemove[$i]['imageUrl'], GALLERY_ROOT.$imagesToRemove[$i]['target']."/small/".$imagesToRemove[$i]['imageUrl']);

                    $imageToRemove = GALLERY_ROOT.$imagesToRemove[$i]['category']."/big/".$imagesToRemove[$i]['imageUrl'];
                	if (file_exists($imageToRemove)) {
                    	@unlink($imageToRemove);
                	}
                	$imageToRemove = GALLERY_ROOT.$imagesToRemove[$i]['category']."/small/".$imagesToRemove[$i]['imageUrl'];
                	if (file_exists($imageToRemove)) {
                    	@unlink($imageToRemove);
                	}
                } else {
                    $imageToRemove = GALLERY_ROOT.$imagesToRemove[$i]['category']."/big/".$imagesToRemove[$i]['imageUrl'];
                	if (file_exists($imageToRemove)) {
                    	@unlink($imageToRemove);
                	}
                	$imageToRemove = GALLERY_ROOT.$imagesToRemove[$i]['category']."/small/".$imagesToRemove[$i]['imageUrl'];
                	if (file_exists($imageToRemove)) {
                    	@unlink($imageToRemove);
                	}
                }
            }
        }
        
        // Clean up temporary files
        if(is_dir(GALLERY_DEFAULT_UPLOADS_PATH."/big")) $this->cleanUpDirectory(GALLERY_DEFAULT_UPLOADS_PATH."/big");
        if(is_dir(GALLERY_DEFAULT_UPLOADS_PATH."/small")) $this->cleanUpDirectory(GALLERY_DEFAULT_UPLOADS_PATH."/small");

        // Export XML and write to back to the file
        if($this->xPath->exportToFile(GALLERY_ROOT.GALLERY_XML_FILENAME, '', '<?xml version="1.0" encoding="utf-8"?>')) {
            return array();
        } else {
            return array('error' => true, 'message' => 'Couldn\'t write xml data file.');
        }
    }

    /**
        @desc Delete provided directory
        @return array
    */
    function deleteDirectory($dirname, $only_empty=false) {
       if (!is_dir($dirname))
           return false;
       $dscan = array(realpath($dirname));
       $darr = array();
       while (!empty($dscan)) {
           $dcur = array_pop($dscan);
           $darr[] = $dcur;
           if ($d=opendir($dcur)) {
               while ($f=readdir($d)) {
                   if ($f=='.' || $f=='..')
                       continue;
                   $f=$dcur.'/'.$f;
                   if (is_dir($f))
                       $dscan[] = $f;
                   else
                      unlink($f);
               }
               closedir($d);
           }
       }
       $i_until = ($only_empty)? 1 : 0;
       for ($i=count($darr)-1; $i>=$i_until; $i--) {
           rmdir($darr[$i]);
       }
       return (($only_empty)? (count(scandir)<=2) : (!is_dir($dirname)));
    }

    function cleanUpDirectory( $targetDir ) {
        if(is_dir($targetDir)) {
            if ($handle = opendir($targetDir)) {
                while (false !== ($file = readdir($handle))) {
                    if ($file != "." && $file != ".." && is_file($targetDir.'/'.$file)) {
                        @unlink($targetDir.'/'.$file);
                    }
                }
                closedir($handle);
            }
        }
    }
    
    function clearCDATA( $string )
    {
    	return preg_replace('/\]\]>$/', '', preg_replace('/^<!\[CDATA/', '', $string));
	}
}

?>